{# ("conf t ; version 9.3(8) Bios:version ; hostname {{ global_config.hostname }} ; vdc {{ global_config.vdc.name }} id {{ global_config.vdc.id }} {% for resource in global_config.vd.resource_limits %}limit-resource {{ resource }} minimum {{ resource.minimum }} maximum {{ resource.maximum }}{% endfor %} ; {% for log in logging level %}logging level {{ log }} {{ log.level }}{% endfor %}{% if global_config.password_strength_check %} ; password_strength_check {% else %} ; no password strength-check{% endif %} ; {% for user in local_users %}username {{ user }} password {{ user.password }} role {{ user.role }}{% if user.passphrase_lifetime is defined %} ; username {{ user }} passphrase  lifetime {{ user.passphrase_lifetime.lifetime }} warntime {{ user.passphrase_lifetime.warntime }} gracetime {{ user.passphrase_lifetime.gracetime }}{% endif%}{%- endfor %}{% if global_config.ip_domain_lookup %} ; ip domain-lookup{% endif %}{% if global_config.ip_domain_name %} ; ip domain-name {{ global_config.ip_domain_name }}{% endif%}{% if global_config.ip_name_server is defined %} ; ip name-server {{ global_config.ip_name_server }}{% endif %} ; {{ global_config.copp_profile }} ; {% for user in snmp_server_users %}snmp-server user {{ user }} {{ user.role }} auth {{ user.auth }} {{ user.priv }} priv {{ user.key }} {{ user.key_type }}}{% endfor %} ; {% for rmon in rmon_events %}rmon event {{ event }} log trap {{ rmon.log_trap }} description {{ rmon.description }} owner {{ rmon.owner }}{% endfor %} ; {% for route in ip_routes %}ip route {{ route}}/{{ route.mask }} {{ route.next_hop }} ; {% for vlan in vlans %}vlan {{ vlan }}{%- endfor %} ; {% for vrf in vrfs %}vrf context {{ vrf }}{% if vrf.domain_name is defined %} ; ip domain-name {{ vrf.domain_name }}{% endif %}{% if vrf.name_server is defined %} ; ip name-server {{ vrf.name_server }}{% endif %}{% endfor %}{% for interface in host_interfaces %}; interface {{ interface }}{% if interface.description is defined %} ; {{ interface.description }}{% endif %}{% if interface.switchport=="False" %} ; no switchport{% endif %}{% if interface.vrf_member is defined %} ; vrf member {{ vrf.vrf_member }}{% endif %}{% if inteface.ip_address is defined %} ; ip address {{ interface.ip_address }}{% endif %}{% if interface.enabled=="false" %} ; shutdown{% else %} ; no shutdown{% endif %}{% endfor %} ; boot nxos {{ global_config.image }} {{ global_config.image_location}}") #}
("conf t ; hostname {{ global_config.hostname }} ")